#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-gadt-plugin
version:              2.3.0.0
visibility:           public
id:                   hls-gadt-plugin-2.3.0.0-JBxiwQ7wujEKuMRaqY4QOd
key:                  hls-gadt-plugin-2.3.0.0-JBxiwQ7wujEKuMRaqY4QOd
license:              Apache-2.0
maintainer:           julytreee@gmail.com
author:               Lei Zhu
synopsis:             Convert to GADT syntax plugin
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server/tree/master/plugins/hls-gadt-plugin#readme>

category:             Development
abi:                  5ddeb68a1b69665067a81a7ace3625d8
exposed:              True
exposed-modules:      Ide.Plugin.GADT
hidden-modules:       Ide.Plugin.GHC
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hls-gadt-plugin-2.3.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hls-gadt-plugin-2.3.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hls-gadt-plugin-2.3.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-gadt-plugin
hs-libraries:         HShls-gadt-plugin-2.3.0.0-JBxiwQ7wujEKuMRaqY4QOd
depends:
    aeson-2.2.2.0-p30NU7EGMRKoAj5LcAXNN base-4.18.2.1 containers-0.6.7
    extra-1.7.16-J2nH1si97LP2pkcRW1gnIU ghc-9.6.6 ghc-boot-th-9.6.6
    ghc-exactprint-1.7.1.0-GrsAftRKdtZBX3MfgGGXGX
    ghcide-2.3.0.0-8hzV1WcjE3LJ8SSkOMpWtc
    hls-plugin-api-2.3.0.0-77mjs7RB43bHJjsly5HGud
    hls-refactor-plugin-2.3.0.0-1hDY45AriXu4uzn4ELZmfm
    lens-5.3.5-7MUa280kiW5NfytVlUfpR lsp-2.2.0.0-KqYdVuca5eSIspYKEV6nVH
    mtl-2.3.1 text-2.0.2 transformers-0.6.1.0
    unordered-containers-0.2.21-KyMpciGvYH9aykbB6p5Z

haddock-interfaces:
    /usr/share/doc/haskell-hls-gadt-plugin/html/hls-gadt-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-gadt-plugin/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

